@@ -3,8 +3,11 @@ import json
 import random
 import string
 from iso8601 import parse_date
-from ..response import ok, error
-from datetime import datetime
+import pytz
+from ..MuviBase import MuviBase
+
+
+arg_tz = pytz.timezone('America/Buenos_Aires')
 
 def _format_card(response):
     if 'card' in response:
@@ -19,7 +22,7 @@ def _format_card(response):
             'expiration_year': response['card']['expiration_year'],
         }
         
-    if 'card_data' in response and not 'tokens' in response['card_data']:
+    if 'card_data' in response and 'tokens' not in response['card_data']:
         return {
             'id': '',
             'card_type': '',
@@ -49,23 +52,25 @@ def _format(response):
         response['status_detail'] = 'accredited'
     elif response['status'] == 'rejected':
         response['status_detail'] = 'rejected'
+
+    date = parse_date(response['date']).astimezone(arg_tz)
     result = {
         'id': response['site_transaction_id'],
         'payment_id': response['id'],
         'transaction_amount': response['amount'] / 100,
-        'date_created': parse_date(response['date']),
+        'date_created': date,
         'status': response['status'],
         'status_detail': response['status_detail'],
         'card': _format_card(response),
-        'processor': 'decidir',
-        'payment_day':datetime.now()
+        'payment_day': date
     }
     return result
 
 
-class Payment:
-    def __init__(self, url: str, private_key: str, public_key: str, merchant_name: str, site_id: str,
+class Payment(MuviBase):
+    def __init__(self, processor: str, url: str, private_key: str, public_key: str, merchant_name: str, site_id: str,
                  site_id_cadena: str):
+        super().__init__(processor)
         self.url = url
         self.private_key = private_key
         self.public_key = public_key
@@ -130,12 +135,10 @@ class Payment:
         if r.status_code < 400:
             if 'card' in payment_data:
                 response['card'] = payment_data['card']
-            return ok(_format(response))
-        return error(response)
+            return self.ok(_format(response), status=r.status_code)
+        return self.error(response, status=r.status_code)
 
     def get(self, payment_id: str):
-        # r = requests.get(self.url + '/payments/{}'.format(payment_id), headers=self.headers)
-        # return ok(_format(r.json()))
         filters = {
             'siteOperationId': payment_id,
             'expand': 'card_data'
@@ -143,9 +146,9 @@ class Payment:
         r = requests.get(self.url + '/payments', params=filters, headers=self.headers)
         list_results = r.json()['results']
         if len(list_results) == 1:
-            return _format(list_results[0])
+            return self.ok(_format(list_results[0]), status=r.status_code)
         else:
-            return error('error_pago_no_encontrado')
+            return self.error(message='error_pago_no_encontrado', status=r.status_code)
 
     def search(self, filters: dict) -> dict:
         # El filter puede ser:
@@ -159,8 +162,8 @@ class Payment:
         r = requests.get(self.url + '/payments', params=filters, headers=self.headers)
         response = r.json()
         response['results'] = [_format(r) for r in response['results']]
-        return ok(response)
+        return self.ok(response, status=r.status_code)
 
     def get_payment_methods(self):
         r = requests.get(self.url + '/payment-methods/1', headers=self.headers)
-        return r.json()
+        return self.ok(r.json(), status=r.status_code)
